summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocument.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficecore/KoDocument.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoDocument.h')
-rw-r--r--lib/kofficecore/KoDocument.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/lib/kofficecore/KoDocument.h b/lib/kofficecore/KoDocument.h
index 4051cca6..ac6de7e8 100644
--- a/lib/kofficecore/KoDocument.h
+++ b/lib/kofficecore/KoDocument.h
@@ -71,16 +71,16 @@ public:
* Constructor.
* The first 4 arguments are the same as the ones passed to KParts::Factory::createPart.
*
- * @param parentWidget the tqparent widget, in case we create a wrapper widget
+ * @param parentWidget the parent widget, in case we create a wrapper widget
* (in single view mode).
* Usually the first argument passed by KParts::Factory::createPart.
* @param widgetName name of the widget.
* @param tqparent may be another KoDocument, or anything else.
* Usually the third argument of KParts::Factory::createPart.
* @param name is used to identify this document via DCOP so you may want to
* pass a meaningful name here which matches the pattern [A-Za-z_][A-Za-z_0-9]*.
* @param singleViewMode determines whether the document may only have one view. In this case
* the @p tqparent must be a TQWidget derived class. KoDocument will then create a wrapper widget
* (KoViewWrapperWidget) which is a child of @p parentWidget.
* This widget can be retrieved by calling widget().
*
@@ -88,7 +88,7 @@ public:
*/
KoDocument( TQWidget* parentWidget,
const char* widgetName,
- TQObject* tqparent,
+ TQObject* parent,
const char* name,
bool singleViewMode = false );
@@ -328,7 +328,7 @@ public:
/**
* Create a new view for the document.
*/
- KoView *createView( TQWidget *tqparent = 0, const char *name = 0 );
+ KoView *createView( TQWidget *parent = 0, const char *name = 0 );
/**
* Adds a view to the document.
@@ -465,11 +465,11 @@ public:
/**
* Creates and shows the start up widget.
* @param tqparent the KoMainWindow used as tqparent for the widget.
* @param alwaysShow always show the widget even if the user has configured it to not show.
* @since 1.5
*/
- virtual void showStartUpWidget(KoMainWindow* tqparent, bool alwaysShow = false);
+ virtual void showStartUpWidget(KoMainWindow* parent, bool alwaysShow = false);
/**
* Sets the modified flag on the document. This means that it has
@@ -908,10 +908,10 @@ public:
/**
* Shows the init dialog when embeding
* @param tqparent the tqparent widget
* @since 1.5
*/
- virtual bool showEmbedInitDialog(TQWidget* tqparent);
+ virtual bool showEmbedInitDialog(TQWidget* parent);
public slots:
/**
@@ -988,7 +988,7 @@ protected:
TQString autoSaveFile( const TQString & path ) const;
- virtual KoView *createViewInstance( TQWidget *tqparent, const char *name ) = 0;
+ virtual KoView *createViewInstance( TQWidget *parent, const char *name ) = 0;
/**
* Loads a document from KReadOnlyPart::m_file (KParts takes care of downloading
@@ -1016,9 +1016,9 @@ protected:
* implement the logic to implement the document instance correctly.
* After initializing the widget should emit a signal called 'documentSelected()' which
* will remove the startupWidget and show the document.
* @param tqparent the tqparent of the to be created widget.
*/
- virtual TQWidget* createCustomDocumentWidget(TQWidget *tqparent);
+ virtual TQWidget* createCustomDocumentWidget(TQWidget *parent);
/**
* OLD XML method. For OASIS just call KoDocumentChild::loadOasisDocument
@@ -1122,12 +1122,12 @@ protected:
/**
* Creates the open widget showed at application start up.
* @param tqparent the tqparent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.
* @since 1.5
*/
- KoOpenPane* createOpenPane( TQWidget* tqparent, KInstance* instance,
+ KoOpenPane* createOpenPane( TQWidget* parent, KInstance* instance,
const TQString& templateType = TQString());
private slots:
@@ -71,16 +71,16 @@ public:
* Usually the first argument passed by KParts::Factory::createPart.
* @param widgetName name of the widget.
- * @param tqparent may be another KoDocument, or anything else.
+ * @param parent may be another KoDocument, or anything else.
* Usually the third argument of KParts::Factory::createPart.
* @param name is used to identify this document via DCOP so you may want to
@@ -71,16 +71,16 @@ public:
* pass a meaningful name here which matches the pattern [A-Za-z_][A-Za-z_0-9]*.
* @param singleViewMode determines whether the document may only have one view. In this case
- * the @p tqparent must be a TQWidget derived class. KoDocument will then create a wrapper widget
+ * the @p parent must be a TQWidget derived class. KoDocument will then create a wrapper widget
* (KoViewWrapperWidget) which is a child of @p parentWidget.
* This widget can be retrieved by calling widget().
@@ -465,11 +465,11 @@ public:
/**
* Creates and shows the start up widget.
- * @param tqparent the KoMainWindow used as tqparent for the widget.
+ * @param parent the KoMainWindow used as parent for the widget.
* @param alwaysShow always show the widget even if the user has configured it to not show.
* @since 1.5
@@ -908,10 +908,10 @@ public:
/**
* Shows the init dialog when embeding
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @since 1.5
*/
@@ -1016,9 +1016,9 @@ protected:
* After initializing the widget should emit a signal called 'documentSelected()' which
* will remove the startupWidget and show the document.
- * @param tqparent the tqparent of the to be created widget.
+ * @param parent the parent of the to be created widget.
*/
@@ -1122,12 +1122,12 @@ protected:
/**
* Creates the open widget showed at application start up.
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param instance the KInstance to be used for KConfig data
* @param templateType the template-type (group) that should be selected on creation.